@@ -122,17 +122,17 @@ def set_request_id(request: Request, response: Response):
         ctx.trace_id = match.group("trace_id")
         ctx.span_id = match.group("span_id")
         ctx.trace_flags = match.group("trace_flags")
-    
-    ctx.x_cloud_trace_context = cloud_trace_context
+        ctx.x_cloud_trace_context = cloud_trace_context
 
     ctx.endpoint_api_userinfo = request.get_header('X-ENDPOINT-API-USERINFO', None)
 
-    request.context.x_cloud_trace_context = cloud_trace_context
+    request.context.x_cloud_trace_context = ctx.x_cloud_trace_context
     request.context.trace_id = ctx.trace_id
     request.context.span_id = ctx.span_id
-    request.context.trace = f"projects/{PROJECT_ID}/traces/{ctx.x_cloud_trace_context}"
+    request.context.trace = f"projects/{PROJECT_ID}/traces/{ctx.trace_id}"
+    ctx.trace = f"projects/{PROJECT_ID}/traces/{ctx.trace_id}"
 
-    response.set_header('X-CLOUD-TRACE-CONTEXT', cloud_trace_context)
+    response.set_header('X-CLOUD-TRACE-CONTEXT', ctx.x_cloud_trace_context)
     return
 
 
